/*
 *
 * 依赖:
 * zepto.min.js
 * lazyload.js
 * image.js
 * caret.js
 * wrapper.js
 *
 * native 需要实现的接口有:
 * void onClickBody();
 * void onDocumentReady();
 * void onHtmlGenerated(String html);
 * void onTextChanged(int length);
 * String provideContent();
 * String providePlaceholder();
 * int provideContentHeight();
 * int provideContentPaddingTop();
 * int provideContentPaddingBottom();
 * int provideContentPaddingLeft();
 * int provideContentPaddingRight();
 *
 * native 可以调用的方法有:
 * void appendMention(long id, String name);
 * void generateHtml();
 * void requestEditorFocus();
 * void startIntervalSave();
 * void stopIntervalSave();
 * void insertImage(int id, String url);
 * void updateImage(int id, String url, int width, int height);
 * void removeImage(int id);
 * void setPlaceholder(String placeholder);
 * void setContentHeight(int height);
 * void setContentVisible(boolean visible);
 * void setBold();
 * void setItalic();
 * void setUnderline();
 * void setStrikeThrough();
 */

function setBodyFontSize(fontSize) {
 	$('body').css('font-size', fontSize + 'px');
}

function setBold(){
    document.execCommand('bold', false, null);
}

function setItalic(){
    document.execCommand('italic', false, null);
}

function setUnderline(){
    document.execCommand('underline', false, null);
}

function setStrikeThrough(){
    document.execCommand('strikeThrough', false, null);
}


function generateHtml() {
	var editor = $('#editor').clone();
	EditorBridge.onHtmlGenerated(editor.html());
}

function requestEditorFocus() {
	$('#editor').focus();
}

// 每隔 10 秒自动保存一次
var intervalId = 0;
function startIntervalSave() {
	stopIntervalSave();
	intervalId = setInterval("generateHtml()", 10000);
}
function stopIntervalSave() {
	clearInterval(intervalId);
}

function setContentHeight(height) {
	$('#editor').css('min-height', height + 'px');
}

function setContentVisible(visible) {
	if (visible) {
		$('#editor').css('visibility', 'visible');
	} else {
		$('#editor').css('visibility', 'hidden');
	}
}

function setupEditor() {
	var editor = $('#editor');

	editor.keydown(function(e) {
		beforeLength = getCaretOffset(editor[0]);
	});

	editor.keyup(function() {
		var afterLength = getCaretOffset(editor[0]);
		EditorBridge.onTextChanged(afterLength);
	});

}

// =================================================================================================

var paddingTop = 16;
var paddingBottom = 16;
var paddingLeft = 16;
var paddingRight = 16;

setContentPaddingTop(paddingTop);
setContentPaddingBottom(paddingBottom);
setContentPaddingLeft(paddingLeft);
setContentPaddingRight(paddingRight);

var bodysize=EditorBridge.provideBodyFontSize();
var contentHeight = EditorBridge.provideContentHeight();;
contentHeight = contentHeight - paddingTop - paddingBottom;
setupEditor();
setBodyFontSize(bodysize)
setContentHeight(contentHeight);
setContentVisible(true);